@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -258,8 +258,8 @@ class ListPerInstanceConfigsPager:
                 sent along with the request as metadata.
         """
         self._method = method
-        self._request = compute.ListPerInstanceConfigsRegionInstanceGroupManagersRequest(
-            request
+        self._request = (
+            compute.ListPerInstanceConfigsRegionInstanceGroupManagersRequest(request)
         )
         self._response = response
         self._metadata = metadata
