@@ -132,6 +132,11 @@ class SslPoliciesTransport(abc.ABC):
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
+            self.aggregated_list: gapic_v1.method.wrap_method(
+                self.aggregated_list,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.delete: gapic_v1.method.wrap_method(
                 self.delete,
                 default_timeout=None,
@@ -173,6 +178,18 @@ class SslPoliciesTransport(abc.ABC):
         """
         raise NotImplementedError()
 
+    @property
+    def aggregated_list(
+        self,
+    ) -> Callable[
+        [compute.AggregatedListSslPoliciesRequest],
+        Union[
+            compute.SslPoliciesAggregatedList,
+            Awaitable[compute.SslPoliciesAggregatedList],
+        ],
+    ]:
+        raise NotImplementedError()
+
     @property
     def delete(
         self,
