@@ -66,6 +66,13 @@ class SslPoliciesRestInterceptor:
 
     .. code-block:: python
         class MyCustomSslPoliciesInterceptor(SslPoliciesRestInterceptor):
+            def pre_aggregated_list(request, metadata):
+                logging.log(f"Received request: {request}")
+                return request, metadata
+
+            def post_aggregated_list(response):
+                logging.log(f"Received response: {response}")
+
             def pre_delete(request, metadata):
                 logging.log(f"Received request: {request}")
                 return request, metadata
@@ -114,6 +121,29 @@ class SslPoliciesRestInterceptor:
 
     """
 
+    def pre_aggregated_list(
+        self,
+        request: compute.AggregatedListSslPoliciesRequest,
+        metadata: Sequence[Tuple[str, str]],
+    ) -> Tuple[compute.AggregatedListSslPoliciesRequest, Sequence[Tuple[str, str]]]:
+        """Pre-rpc interceptor for aggregated_list
+
+        Override in a subclass to manipulate the request or metadata
+        before they are sent to the SslPolicies server.
+        """
+        return request, metadata
+
+    def post_aggregated_list(
+        self, response: compute.SslPoliciesAggregatedList
+    ) -> compute.SslPoliciesAggregatedList:
+        """Post-rpc interceptor for aggregated_list
+
+        Override in a subclass to manipulate the response
+        after it is returned by the SslPolicies server but before
+        it is returned to user code.
+        """
+        return response
+
     def pre_delete(
         self,
         request: compute.DeleteSslPolicyRequest,
@@ -346,6 +376,93 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
         self._interceptor = interceptor or SslPoliciesRestInterceptor()
         self._prep_wrapped_messages(client_info)
 
+    class _AggregatedList(SslPoliciesRestStub):
+        def __hash__(self):
+            return hash("AggregatedList")
+
+        __REQUIRED_FIELDS_DEFAULT_VALUES: Dict[str, str] = {}
+
+        @classmethod
+        def _get_unset_required_fields(cls, message_dict):
+            return {
+                k: v
+                for k, v in cls.__REQUIRED_FIELDS_DEFAULT_VALUES.items()
+                if k not in message_dict
+            }
+
+        def __call__(
+            self,
+            request: compute.AggregatedListSslPoliciesRequest,
+            *,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+        ) -> compute.SslPoliciesAggregatedList:
+            r"""Call the aggregated list method over HTTP.
+
+            Args:
+                request (~.compute.AggregatedListSslPoliciesRequest):
+                    The request object. A request message for
+                SslPolicies.AggregatedList. See the
+                method description for details.
+
+                retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                    should be retried.
+                timeout (float): The timeout for this request.
+                metadata (Sequence[Tuple[str, str]]): Strings which should be
+                    sent along with the request as metadata.
+
+            Returns:
+                ~.compute.SslPoliciesAggregatedList:
+
+            """
+
+            http_options: List[Dict[str, str]] = [
+                {
+                    "method": "get",
+                    "uri": "/compute/v1/projects/{project}/aggregated/sslPolicies",
+                },
+            ]
+            request, metadata = self._interceptor.pre_aggregated_list(request, metadata)
+            pb_request = compute.AggregatedListSslPoliciesRequest.pb(request)
+            transcoded_request = path_template.transcode(http_options, pb_request)
+
+            uri = transcoded_request["uri"]
+            method = transcoded_request["method"]
+
+            # Jsonify the query params
+            query_params = json.loads(
+                json_format.MessageToJson(
+                    transcoded_request["query_params"],
+                    including_default_value_fields=False,
+                    use_integers_for_enums=False,
+                )
+            )
+            query_params.update(self._get_unset_required_fields(query_params))
+
+            # Send the request
+            headers = dict(metadata)
+            headers["Content-Type"] = "application/json"
+            response = getattr(self._session, method)(
+                "{host}{uri}".format(host=self._host, uri=uri),
+                timeout=timeout,
+                headers=headers,
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
+            )
+
+            # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
+            # subclass.
+            if response.status_code >= 400:
+                raise core_exceptions.from_http_response(response)
+
+            # Return the response
+            resp = compute.SslPoliciesAggregatedList()
+            pb_resp = compute.SslPoliciesAggregatedList.pb(resp)
+
+            json_format.Parse(response.content, pb_resp, ignore_unknown_fields=True)
+            resp = self._interceptor.post_aggregated_list(resp)
+            return resp
+
     class _Delete(SslPoliciesRestStub):
         def __hash__(self):
             return hash("Delete")
@@ -432,7 +549,7 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
                 "{host}{uri}".format(host=self._host, uri=uri),
                 timeout=timeout,
                 headers=headers,
-                params=rest_helpers.flatten_query_params(query_params),
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
             )
 
             # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
@@ -525,7 +642,7 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
                 "{host}{uri}".format(host=self._host, uri=uri),
                 timeout=timeout,
                 headers=headers,
-                params=rest_helpers.flatten_query_params(query_params),
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
             )
 
             # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
@@ -635,7 +752,7 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
                 "{host}{uri}".format(host=self._host, uri=uri),
                 timeout=timeout,
                 headers=headers,
-                params=rest_helpers.flatten_query_params(query_params),
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
                 data=body,
             )
 
@@ -723,7 +840,7 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
                 "{host}{uri}".format(host=self._host, uri=uri),
                 timeout=timeout,
                 headers=headers,
-                params=rest_helpers.flatten_query_params(query_params),
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
             )
 
             # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
@@ -812,7 +929,7 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
                 "{host}{uri}".format(host=self._host, uri=uri),
                 timeout=timeout,
                 headers=headers,
-                params=rest_helpers.flatten_query_params(query_params),
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
             )
 
             # In case of error, raise the appropriate core_exceptions.GoogleAPICallError exception
@@ -922,7 +1039,7 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
                 "{host}{uri}".format(host=self._host, uri=uri),
                 timeout=timeout,
                 headers=headers,
-                params=rest_helpers.flatten_query_params(query_params),
+                params=rest_helpers.flatten_query_params(query_params, strict=True),
                 data=body,
             )
 
@@ -939,6 +1056,16 @@ class SslPoliciesRestTransport(SslPoliciesTransport):
             resp = self._interceptor.post_patch(resp)
             return resp
 
+    @property
+    def aggregated_list(
+        self,
+    ) -> Callable[
+        [compute.AggregatedListSslPoliciesRequest], compute.SslPoliciesAggregatedList
+    ]:
+        # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
+        # In C++ this would require a dynamic_cast
+        return self._AggregatedList(self._session, self._host, self._interceptor)  # type: ignore
+
     @property
     def delete(self) -> Callable[[compute.DeleteSslPolicyRequest], compute.Operation]:
         # The return type is fine, but mypy isn't sophisticated enough to determine what's going on here.
