@@ -157,6 +157,11 @@ class TargetVpnGatewaysTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.set_labels: gapic_v1.method.wrap_method(
+                self.set_labels,
+                default_timeout=None,
+                client_info=client_info,
+            ),
         }
 
     def close(self):
@@ -216,6 +221,15 @@ class TargetVpnGatewaysTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def set_labels(
+        self,
+    ) -> Callable[
+        [compute.SetLabelsTargetVpnGatewayRequest],
+        Union[compute.Operation, Awaitable[compute.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def kind(self) -> str:
         raise NotImplementedError()
