@@ -74,6 +74,7 @@ from .compute import (
     AggregatedListSecurityPoliciesRequest,
     AggregatedListServiceAttachmentsRequest,
     AggregatedListSslCertificatesRequest,
+    AggregatedListSslPoliciesRequest,
     AggregatedListSubnetworksRequest,
     AggregatedListTargetHttpProxiesRequest,
     AggregatedListTargetHttpsProxiesRequest,
@@ -218,8 +219,10 @@ from .compute import (
     DeleteRegionOperationResponse,
     DeleteRegionSecurityPolicyRequest,
     DeleteRegionSslCertificateRequest,
+    DeleteRegionSslPolicyRequest,
     DeleteRegionTargetHttpProxyRequest,
     DeleteRegionTargetHttpsProxyRequest,
+    DeleteRegionTargetTcpProxyRequest,
     DeleteRegionUrlMapRequest,
     DeleteReservationRequest,
     DeleteResourcePolicyRequest,
@@ -259,6 +262,7 @@ from .compute import (
     DiskInstantiationConfig,
     DiskList,
     DiskMoveRequest,
+    DiskParams,
     DisksAddResourcePoliciesRequest,
     DisksRemoveResourcePoliciesRequest,
     DisksResizeRequest,
@@ -333,6 +337,7 @@ from .compute import (
     GetHealthCheckRequest,
     GetHealthRegionBackendServiceRequest,
     GetHealthTargetPoolRequest,
+    GetIamPolicyBackendServiceRequest,
     GetIamPolicyDiskRequest,
     GetIamPolicyFirewallPolicyRequest,
     GetIamPolicyImageRequest,
@@ -343,6 +348,7 @@ from .compute import (
     GetIamPolicyNetworkFirewallPolicyRequest,
     GetIamPolicyNodeGroupRequest,
     GetIamPolicyNodeTemplateRequest,
+    GetIamPolicyRegionBackendServiceRequest,
     GetIamPolicyRegionDiskRequest,
     GetIamPolicyRegionNetworkFirewallPolicyRequest,
     GetIamPolicyReservationRequest,
@@ -391,8 +397,10 @@ from .compute import (
     GetRegionRequest,
     GetRegionSecurityPolicyRequest,
     GetRegionSslCertificateRequest,
+    GetRegionSslPolicyRequest,
     GetRegionTargetHttpProxyRequest,
     GetRegionTargetHttpsProxyRequest,
+    GetRegionTargetTcpProxyRequest,
     GetRegionUrlMapRequest,
     GetReservationRequest,
     GetResourcePolicyRequest,
@@ -515,8 +523,10 @@ from .compute import (
     InsertRegionNotificationEndpointRequest,
     InsertRegionSecurityPolicyRequest,
     InsertRegionSslCertificateRequest,
+    InsertRegionSslPolicyRequest,
     InsertRegionTargetHttpProxyRequest,
     InsertRegionTargetHttpsProxyRequest,
+    InsertRegionTargetTcpProxyRequest,
     InsertRegionUrlMapRequest,
     InsertReservationRequest,
     InsertResourcePolicyRequest,
@@ -541,6 +551,8 @@ from .compute import (
     InsertVpnTunnelRequest,
     Instance,
     InstanceAggregatedList,
+    InstanceConsumptionData,
+    InstanceConsumptionInfo,
     InstanceGroup,
     InstanceGroupAggregatedList,
     InstanceGroupList,
@@ -630,6 +642,7 @@ from .compute import (
     ListAddressesRequest,
     ListAssociationsFirewallPolicyRequest,
     ListAutoscalersRequest,
+    ListAvailableFeaturesRegionSslPoliciesRequest,
     ListAvailableFeaturesSslPoliciesRequest,
     ListBackendBucketsRequest,
     ListBackendServicesRequest,
@@ -696,8 +709,10 @@ from .compute import (
     ListRegionSecurityPoliciesRequest,
     ListRegionsRequest,
     ListRegionSslCertificatesRequest,
+    ListRegionSslPoliciesRequest,
     ListRegionTargetHttpProxiesRequest,
     ListRegionTargetHttpsProxiesRequest,
+    ListRegionTargetTcpProxiesRequest,
     ListRegionUrlMapsRequest,
     ListReservationsRequest,
     ListResourcePoliciesRequest,
@@ -846,6 +861,7 @@ from .compute import (
     PatchRegionInstanceGroupManagerRequest,
     PatchRegionNetworkFirewallPolicyRequest,
     PatchRegionSecurityPolicyRequest,
+    PatchRegionSslPolicyRequest,
     PatchRegionTargetHttpsProxyRequest,
     PatchRegionUrlMapRequest,
     PatchRouterRequest,
@@ -1005,6 +1021,7 @@ from .compute import (
     SecurityPolicyAdaptiveProtectionConfig,
     SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig,
     SecurityPolicyAdvancedOptionsConfig,
+    SecurityPolicyAdvancedOptionsConfigJsonCustomConfig,
     SecurityPolicyDdosProtectionConfig,
     SecurityPolicyList,
     SecurityPolicyRecaptchaOptionsConfig,
@@ -1040,6 +1057,7 @@ from .compute import (
     SetDiskAutoDeleteInstanceRequest,
     SetEdgeSecurityPolicyBackendBucketRequest,
     SetEdgeSecurityPolicyBackendServiceRequest,
+    SetIamPolicyBackendServiceRequest,
     SetIamPolicyDiskRequest,
     SetIamPolicyFirewallPolicyRequest,
     SetIamPolicyImageRequest,
@@ -1050,6 +1068,7 @@ from .compute import (
     SetIamPolicyNetworkFirewallPolicyRequest,
     SetIamPolicyNodeGroupRequest,
     SetIamPolicyNodeTemplateRequest,
+    SetIamPolicyRegionBackendServiceRequest,
     SetIamPolicyRegionDiskRequest,
     SetIamPolicyRegionNetworkFirewallPolicyRequest,
     SetIamPolicyReservationRequest,
@@ -1059,15 +1078,22 @@ from .compute import (
     SetIamPolicySubnetworkRequest,
     SetInstanceTemplateInstanceGroupManagerRequest,
     SetInstanceTemplateRegionInstanceGroupManagerRequest,
+    SetLabelsAddressRequest,
     SetLabelsDiskRequest,
     SetLabelsExternalVpnGatewayRequest,
     SetLabelsForwardingRuleRequest,
+    SetLabelsGlobalAddressRequest,
     SetLabelsGlobalForwardingRuleRequest,
     SetLabelsImageRequest,
     SetLabelsInstanceRequest,
+    SetLabelsInterconnectAttachmentRequest,
+    SetLabelsInterconnectRequest,
     SetLabelsRegionDiskRequest,
+    SetLabelsSecurityPolicyRequest,
     SetLabelsSnapshotRequest,
+    SetLabelsTargetVpnGatewayRequest,
     SetLabelsVpnGatewayRequest,
+    SetLabelsVpnTunnelRequest,
     SetMachineResourcesInstanceRequest,
     SetMachineTypeInstanceRequest,
     SetMetadataInstanceRequest,
@@ -1118,8 +1144,10 @@ from .compute import (
     SslCertificateSelfManagedSslCertificate,
     SslCertificatesScopedList,
     SSLHealthCheck,
+    SslPoliciesAggregatedList,
     SslPoliciesList,
     SslPoliciesListAvailableFeaturesResponse,
+    SslPoliciesScopedList,
     SslPolicy,
     SslPolicyReference,
     StartInstanceRequest,
@@ -1341,6 +1369,7 @@ __all__ = (
     "AggregatedListSecurityPoliciesRequest",
     "AggregatedListServiceAttachmentsRequest",
     "AggregatedListSslCertificatesRequest",
+    "AggregatedListSslPoliciesRequest",
     "AggregatedListSubnetworksRequest",
     "AggregatedListTargetHttpProxiesRequest",
     "AggregatedListTargetHttpsProxiesRequest",
@@ -1485,8 +1514,10 @@ __all__ = (
     "DeleteRegionOperationResponse",
     "DeleteRegionSecurityPolicyRequest",
     "DeleteRegionSslCertificateRequest",
+    "DeleteRegionSslPolicyRequest",
     "DeleteRegionTargetHttpProxyRequest",
     "DeleteRegionTargetHttpsProxyRequest",
+    "DeleteRegionTargetTcpProxyRequest",
     "DeleteRegionUrlMapRequest",
     "DeleteReservationRequest",
     "DeleteResourcePolicyRequest",
@@ -1526,6 +1557,7 @@ __all__ = (
     "DiskInstantiationConfig",
     "DiskList",
     "DiskMoveRequest",
+    "DiskParams",
     "DisksAddResourcePoliciesRequest",
     "DisksRemoveResourcePoliciesRequest",
     "DisksResizeRequest",
@@ -1600,6 +1632,7 @@ __all__ = (
     "GetHealthCheckRequest",
     "GetHealthRegionBackendServiceRequest",
     "GetHealthTargetPoolRequest",
+    "GetIamPolicyBackendServiceRequest",
     "GetIamPolicyDiskRequest",
     "GetIamPolicyFirewallPolicyRequest",
     "GetIamPolicyImageRequest",
@@ -1610,6 +1643,7 @@ __all__ = (
     "GetIamPolicyNetworkFirewallPolicyRequest",
     "GetIamPolicyNodeGroupRequest",
     "GetIamPolicyNodeTemplateRequest",
+    "GetIamPolicyRegionBackendServiceRequest",
     "GetIamPolicyRegionDiskRequest",
     "GetIamPolicyRegionNetworkFirewallPolicyRequest",
     "GetIamPolicyReservationRequest",
@@ -1658,8 +1692,10 @@ __all__ = (
     "GetRegionRequest",
     "GetRegionSecurityPolicyRequest",
     "GetRegionSslCertificateRequest",
+    "GetRegionSslPolicyRequest",
     "GetRegionTargetHttpProxyRequest",
     "GetRegionTargetHttpsProxyRequest",
+    "GetRegionTargetTcpProxyRequest",
     "GetRegionUrlMapRequest",
     "GetReservationRequest",
     "GetResourcePolicyRequest",
@@ -1782,8 +1818,10 @@ __all__ = (
     "InsertRegionNotificationEndpointRequest",
     "InsertRegionSecurityPolicyRequest",
     "InsertRegionSslCertificateRequest",
+    "InsertRegionSslPolicyRequest",
     "InsertRegionTargetHttpProxyRequest",
     "InsertRegionTargetHttpsProxyRequest",
+    "InsertRegionTargetTcpProxyRequest",
     "InsertRegionUrlMapRequest",
     "InsertReservationRequest",
     "InsertResourcePolicyRequest",
@@ -1808,6 +1846,8 @@ __all__ = (
     "InsertVpnTunnelRequest",
     "Instance",
     "InstanceAggregatedList",
+    "InstanceConsumptionData",
+    "InstanceConsumptionInfo",
     "InstanceGroup",
     "InstanceGroupAggregatedList",
     "InstanceGroupList",
@@ -1897,6 +1937,7 @@ __all__ = (
     "ListAddressesRequest",
     "ListAssociationsFirewallPolicyRequest",
     "ListAutoscalersRequest",
+    "ListAvailableFeaturesRegionSslPoliciesRequest",
     "ListAvailableFeaturesSslPoliciesRequest",
     "ListBackendBucketsRequest",
     "ListBackendServicesRequest",
@@ -1963,8 +2004,10 @@ __all__ = (
     "ListRegionSecurityPoliciesRequest",
     "ListRegionsRequest",
     "ListRegionSslCertificatesRequest",
+    "ListRegionSslPoliciesRequest",
     "ListRegionTargetHttpProxiesRequest",
     "ListRegionTargetHttpsProxiesRequest",
+    "ListRegionTargetTcpProxiesRequest",
     "ListRegionUrlMapsRequest",
     "ListReservationsRequest",
     "ListResourcePoliciesRequest",
@@ -2113,6 +2156,7 @@ __all__ = (
     "PatchRegionInstanceGroupManagerRequest",
     "PatchRegionNetworkFirewallPolicyRequest",
     "PatchRegionSecurityPolicyRequest",
+    "PatchRegionSslPolicyRequest",
     "PatchRegionTargetHttpsProxyRequest",
     "PatchRegionUrlMapRequest",
     "PatchRouterRequest",
@@ -2272,6 +2316,7 @@ __all__ = (
     "SecurityPolicyAdaptiveProtectionConfig",
     "SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig",
     "SecurityPolicyAdvancedOptionsConfig",
+    "SecurityPolicyAdvancedOptionsConfigJsonCustomConfig",
     "SecurityPolicyDdosProtectionConfig",
     "SecurityPolicyList",
     "SecurityPolicyRecaptchaOptionsConfig",
@@ -2307,6 +2352,7 @@ __all__ = (
     "SetDiskAutoDeleteInstanceRequest",
     "SetEdgeSecurityPolicyBackendBucketRequest",
     "SetEdgeSecurityPolicyBackendServiceRequest",
+    "SetIamPolicyBackendServiceRequest",
     "SetIamPolicyDiskRequest",
     "SetIamPolicyFirewallPolicyRequest",
     "SetIamPolicyImageRequest",
@@ -2317,6 +2363,7 @@ __all__ = (
     "SetIamPolicyNetworkFirewallPolicyRequest",
     "SetIamPolicyNodeGroupRequest",
     "SetIamPolicyNodeTemplateRequest",
+    "SetIamPolicyRegionBackendServiceRequest",
     "SetIamPolicyRegionDiskRequest",
     "SetIamPolicyRegionNetworkFirewallPolicyRequest",
     "SetIamPolicyReservationRequest",
@@ -2326,15 +2373,22 @@ __all__ = (
     "SetIamPolicySubnetworkRequest",
     "SetInstanceTemplateInstanceGroupManagerRequest",
     "SetInstanceTemplateRegionInstanceGroupManagerRequest",
+    "SetLabelsAddressRequest",
     "SetLabelsDiskRequest",
     "SetLabelsExternalVpnGatewayRequest",
     "SetLabelsForwardingRuleRequest",
+    "SetLabelsGlobalAddressRequest",
     "SetLabelsGlobalForwardingRuleRequest",
     "SetLabelsImageRequest",
     "SetLabelsInstanceRequest",
+    "SetLabelsInterconnectAttachmentRequest",
+    "SetLabelsInterconnectRequest",
     "SetLabelsRegionDiskRequest",
+    "SetLabelsSecurityPolicyRequest",
     "SetLabelsSnapshotRequest",
+    "SetLabelsTargetVpnGatewayRequest",
     "SetLabelsVpnGatewayRequest",
+    "SetLabelsVpnTunnelRequest",
     "SetMachineResourcesInstanceRequest",
     "SetMachineTypeInstanceRequest",
     "SetMetadataInstanceRequest",
@@ -2385,8 +2439,10 @@ __all__ = (
     "SslCertificateSelfManagedSslCertificate",
     "SslCertificatesScopedList",
     "SSLHealthCheck",
+    "SslPoliciesAggregatedList",
     "SslPoliciesList",
     "SslPoliciesListAvailableFeaturesResponse",
+    "SslPoliciesScopedList",
     "SslPolicy",
     "SslPolicyReference",
     "StartInstanceRequest",
