@@ -18,8 +18,8 @@ import os
 # try/except added for compatibility with python < 3.8
 try:
     from unittest import mock
-    from unittest.mock import AsyncMock
-except ImportError:
+    from unittest.mock import AsyncMock  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
     import mock
 
 import grpc
@@ -30,10 +30,11 @@ import json
 import math
 import pytest
 from proto.marshal.rules.dates import DurationRule, TimestampRule
-
+from proto.marshal.rules import wrappers
 from requests import Response
 from requests import Request, PreparedRequest
 from requests.sessions import Session
+from google.protobuf import json_format
 
 from google.api_core import client_options
 from google.api_core import exceptions as core_exceptions
@@ -589,6 +590,7 @@ def test_bulk_insert_rest(request_type):
                 "enable_nested_virtualization": True,
                 "enable_uefi_networking": True,
                 "threads_per_core": 1689,
+                "visible_core_count": 1918,
             },
             "can_ip_forward": True,
             "confidential_instance_config": {"enable_confidential_compute": True},
@@ -607,6 +609,7 @@ def test_bulk_insert_rest(request_type):
                         "sha256": "sha256_value",
                     },
                     "disk_size_gb": 1261,
+                    "force_attach": True,
                     "guest_os_features": [{"type_": "type__value"}],
                     "index": 536,
                     "initialize_params": {
@@ -619,6 +622,7 @@ def test_bulk_insert_rest(request_type):
                         "licenses": ["licenses_value1", "licenses_value2"],
                         "on_update_action": "on_update_action_value",
                         "provisioned_iops": 1740,
+                        "resource_manager_tags": {},
                         "resource_policies": [
                             "resource_policies_value1",
                             "resource_policies_value2",
@@ -953,7 +957,7 @@ def test_bulk_insert_rest_interceptors(null_interceptor):
             ("cephalopod", "squid"),
         ]
         pre.return_value = request, metadata
-        post.return_value = compute.Operation
+        post.return_value = compute.Operation()
 
         client.bulk_insert(
             request,
@@ -984,6 +988,7 @@ def test_bulk_insert_rest_bad_request(
                 "enable_nested_virtualization": True,
                 "enable_uefi_networking": True,
                 "threads_per_core": 1689,
+                "visible_core_count": 1918,
             },
             "can_ip_forward": True,
             "confidential_instance_config": {"enable_confidential_compute": True},
@@ -1002,6 +1007,7 @@ def test_bulk_insert_rest_bad_request(
                         "sha256": "sha256_value",
                     },
                     "disk_size_gb": 1261,
+                    "force_attach": True,
                     "guest_os_features": [{"type_": "type__value"}],
                     "index": 536,
                     "initialize_params": {
@@ -1014,6 +1020,7 @@ def test_bulk_insert_rest_bad_request(
                         "licenses": ["licenses_value1", "licenses_value2"],
                         "on_update_action": "on_update_action_value",
                         "provisioned_iops": 1740,
+                        "resource_manager_tags": {},
                         "resource_policies": [
                             "resource_policies_value1",
                             "resource_policies_value2",
@@ -1245,6 +1252,7 @@ def test_bulk_insert_unary_rest(request_type):
                 "enable_nested_virtualization": True,
                 "enable_uefi_networking": True,
                 "threads_per_core": 1689,
+                "visible_core_count": 1918,
             },
             "can_ip_forward": True,
             "confidential_instance_config": {"enable_confidential_compute": True},
@@ -1263,6 +1271,7 @@ def test_bulk_insert_unary_rest(request_type):
                         "sha256": "sha256_value",
                     },
                     "disk_size_gb": 1261,
+                    "force_attach": True,
                     "guest_os_features": [{"type_": "type__value"}],
                     "index": 536,
                     "initialize_params": {
@@ -1275,6 +1284,7 @@ def test_bulk_insert_unary_rest(request_type):
                         "licenses": ["licenses_value1", "licenses_value2"],
                         "on_update_action": "on_update_action_value",
                         "provisioned_iops": 1740,
+                        "resource_manager_tags": {},
                         "resource_policies": [
                             "resource_policies_value1",
                             "resource_policies_value2",
@@ -1587,7 +1597,7 @@ def test_bulk_insert_unary_rest_interceptors(null_interceptor):
             ("cephalopod", "squid"),
         ]
         pre.return_value = request, metadata
-        post.return_value = compute.Operation
+        post.return_value = compute.Operation()
 
         client.bulk_insert_unary(
             request,
@@ -1618,6 +1628,7 @@ def test_bulk_insert_unary_rest_bad_request(
                 "enable_nested_virtualization": True,
                 "enable_uefi_networking": True,
                 "threads_per_core": 1689,
+                "visible_core_count": 1918,
             },
             "can_ip_forward": True,
             "confidential_instance_config": {"enable_confidential_compute": True},
@@ -1636,6 +1647,7 @@ def test_bulk_insert_unary_rest_bad_request(
                         "sha256": "sha256_value",
                     },
                     "disk_size_gb": 1261,
+                    "force_attach": True,
                     "guest_os_features": [{"type_": "type__value"}],
                     "index": 536,
                     "initialize_params": {
@@ -1648,6 +1660,7 @@ def test_bulk_insert_unary_rest_bad_request(
                         "licenses": ["licenses_value1", "licenses_value2"],
                         "on_update_action": "on_update_action_value",
                         "provisioned_iops": 1740,
+                        "resource_manager_tags": {},
                         "resource_policies": [
                             "resource_policies_value1",
                             "resource_policies_value2",
